OC.L10N.register(
    "recommendations",
    {
    "Recently commented" : "Недавно прокомментировано",
    "Recently edited" : "Недавно отредактировано",
    "Recently shared" : "Недавно опубликовано",
    "Recommendations" : "Рекомендации",
    "Shows recommended files" : "Показывает рекомендуемые файлы",
    "Shows recommended files for quick access of files and folders with recent activity" : "Показывает рекомендуемые файлы для быстрого доступа к файлам и папкам с недавней активностью",
    "Enabled" : "Включено"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
